@@ -14,13 +14,19 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
-# entity types
-ENTITY_TYPE_POWER_MODULE = 0x0a
-ENTITY_TYPE_COOLING_UNIT = 0x1e
-ENTITY_TYPE_PICMG_FRONT_BOARD = 0xa0
-ENTITY_TYPE_PICMG_REAR_TRANSITION_MODULE = 0xc0
-ENTITY_TYPE_PICMG_ADVANCED_MC = 0xc1
-ENTITY_TYPE_PICMG_MICROTCA_CARRIER_HUB = 0xc2
-ENTITY_TYPE_PICMG_SHELF_MANAGEMENT_CONTROLLER = 0xf0
-ENTITY_TYPE_PICMG_FILTRATION_UNIT = 0xf1
-ENTITY_TYPE_PICMG_SHELF_FRU_INFORMATION = 0xf2
+# Entity ID assignments
+ENTITY_ID_CPU = 0x03
+ENTITY_ID_BASEBOARD = 0x07
+ENTITY_ID_POWER_MODULE = 0x0a
+ENTITY_ID_COOLING_UNIT = 0x1e
+ENTITY_ID_AIR_INLET = 0x37
+ENTITY_ID_DCMI_AIR_INLET = 0x40
+ENTITY_ID_DCMI_CPU = 0x41
+ENTITY_ID_DCMI_BASEBOARD = 0x42
+ENTITY_ID_PICMG_FRONT_BOARD = 0xa0
+ENTITY_ID_PICMG_REAR_TRANSITION_MODULE = 0xc0
+ENTITY_ID_PICMG_ADVANCED_MC = 0xc1
+ENTITY_ID_PICMG_MICROTCA_CARRIER_HUB = 0xc2
+ENTITY_ID_PICMG_SHELF_MANAGEMENT_CONTROLLER = 0xf0
+ENTITY_ID_PICMG_FILTRATION_UNIT = 0xf1
+ENTITY_ID_PICMG_SHELF_FRU_INFORMATION = 0xf2
