@@ -12,7 +12,10 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+
+from .msgs.constants import COMPLETION_CODE_DESCR
+
 
 class DecodingError(Exception):
     """Error on message decoding."""
@@ -24,18 +27,27 @@ class EncodingError(Exception):
     pass
 
 
-class TimeoutError(Exception):
+class IpmiTimeoutError(Exception):
     """Timeout occurred."""
     pass
 
 
 class CompletionCodeError(Exception):
     """IPMI completion code not OK."""
-    def __init__(self, cc):
+    def __init__(self, cc, cmd_id=None):
         self.cc = cc
+        self.cc_desc = self.find_cc_desc(cc)
 
     def __str__(self):
-        return "%s cc=0x%02x" % (self.__class__.__name__, self.cc)
+        return "%s cc=0x%02x desc=%s" \
+            % (self.__class__.__name__, self.cc, self.cc_desc)
+
+    @staticmethod
+    def find_cc_desc(error_cc):
+        for cc in COMPLETION_CODE_DESCR:
+            if error_cc == cc[0]:
+                return cc[1]
+        return "Unknown error description"
 
 
 class NotSupportedError(Exception):
