@@ -12,16 +12,15 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
-from pyipmi.errors import DecodingError, CompletionCodeError, RetryError
-from pyipmi.utils import check_completion_code, ByteBuffer
-from pyipmi.msgs import create_request_by_name
-from pyipmi.msgs import constants
+from .utils import check_completion_code
+from .msgs import create_request_by_name
 
 EVENT_ASSERTION = 0
 EVENT_DEASSERTION = 1
 
+
 class Event(object):
     def set_event_receiver(self, ipmb_address, lun):
         req = create_request_by_name('SetEventReceiver')
