@@ -12,16 +12,21 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
 from .ipmitool import Ipmitool
 from .aardvark import Aardvark
+from .mock import Mock
+from .rmcp import Rmcp
 
 INTERFACES = [
-        Ipmitool,
-        Aardvark,
+    Ipmitool,
+    Aardvark,
+    Mock,
+    Rmcp,
 ]
 
+
 def create_interface(interface, *args, **kwargs):
     for intf in INTERFACES:
         if intf.NAME == interface:
@@ -29,4 +34,3 @@ def create_interface(interface, *args, **kwargs):
             return intf
 
     raise RuntimeError('unknown interface with name %s' % interface)
-
