@@ -20,7 +20,7 @@ from array import array
 from ..msgs import create_message, encode_message, decode_message
 from ..errors import IpmiTimeoutError
 from ..logger import log
-from ..interfaces.ipmb import IpmbHeader, checksum, rx_filter, encode_ipmb_msg
+from ..interfaces.ipmb import IpmbHeaderReq, checksum, rx_filter, encode_ipmb_msg
 
 try:
     import pyaardvark
@@ -34,10 +34,11 @@ class Aardvark(object):
     NAME = 'aardvark'
 
     def __init__(self, slave_address=0x20, port=0, serial_number=None,
-                 enable_i2c_pullups=True):
+                 enable_i2c_pullups=None, enable_target_power=None):
         if pyaardvark is None:
             raise RuntimeError('No pyaardvark module found. You can not '
                                'use this interface.')
+
         self.slave_address = slave_address
         self.timeout = 0.25
         self.max_retries = 3
@@ -46,6 +47,11 @@ class Aardvark(object):
         self._dev = pyaardvark.open(port, serial_number)
         self._dev.enable_i2c_slave(self.slave_address >> 1)
 
+        if enable_i2c_pullups:
+            self.enable_pullups(enable_i2c_pullups)
+        if enable_target_power:
+            self.enable_target_power(enable_target_power)
+
     def enable_pullups(self, enabled):
         self._dev.i2c_pullups = enabled
 
@@ -63,7 +69,7 @@ class Aardvark(object):
         self._dev.close()
 
     def is_ipmc_accessible(self, target):
-        header = IpmbHeader()
+        header = IpmbHeaderReq()
         header.netfn = 6
         header.rs_lun = 0
         header.rs_sa = target.ipmb_address
@@ -136,7 +142,7 @@ class Aardvark(object):
         self._inc_sequence_number()
 
         # assemble IPMB header
-        header = IpmbHeader()
+        header = IpmbHeaderReq()
         header.netfn = netfn
         header.rs_lun = lun
         header.rs_sa = target.ipmb_address
@@ -152,9 +158,12 @@ class Aardvark(object):
                 rx_data = self._receive_raw(header)
                 break
             except IpmiTimeoutError:
-                log().warning('I2C transaction timed out'),
+                pass
+            except IOError:
+                pass
 
             retries += 1
+            time.sleep(retries*0.2)
 
         else:
             raise IpmiTimeoutError()
@@ -193,7 +202,7 @@ class Aardvark(object):
                                          netfn=req.netfn,
                                          cmdid=req.cmdid,
                                          payload=encode_message(req))
-        rsp = create_message(req.cmdid, req.netfn + 1)
+        rsp = create_message(req.netfn + 1, req.cmdid, req.group_extension)
         decode_message(rsp, rx_data)
 
         log().debug('IPMI Response [%s])', rsp)
