@@ -1,3 +1,19 @@
+# Copyright (c) 2018  Kontron Europe GmbH
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+
 import socket
 import struct
 import hashlib
@@ -13,7 +29,7 @@ from ..msgs import (create_message, create_request_by_name,
 from ..messaging import ChannelAuthenticationCapabilities
 from ..errors import DecodingError, NotSupportedError
 from ..logger import log
-from ..interfaces.ipmb import (IpmbHeader, encode_ipmb_msg,
+from ..interfaces.ipmb import (IpmbHeaderReq, encode_ipmb_msg,
                                encode_bridged_message, decode_bridged_message,
                                rx_filter)
 from ..utils import check_completion_code
@@ -126,9 +142,9 @@ class AsfMsg(object):
 
     def __str__(self):
         if self.data:
-            return ' '.join('%02x' % ord(b) for b in self.data)
+            return ' '.join('%02x' % b for b in array('B', self.data))
         if self.sdu:
-            return ' '.join('%02x' % ord(b) for b in self.sdu)
+            return ' '.join('%02x' % b for b in array('B', self.sdu))
         return ''
 
 
@@ -331,7 +347,7 @@ class Rmcp(object):
 
     def _send_ipmi_msg(self, data):
         log().debug('IPMI TX: {:s}'.format(
-            ''.join('%02x ' % b for b in array('B', data))))
+            ' '.join('%02x' % b for b in array('B', data))))
         ipmi = IpmiMsg(self._session)
         tx_data = ipmi.pack(data)
         self._send_rmcp_msg(tx_data, RMCP_CLASS_IPMI)
@@ -343,7 +359,7 @@ class Rmcp(object):
         msg = IpmiMsg()
         data = msg.unpack(pdu)
         log().debug('IPMI RX: {:s}'.format(
-            ''.join('%02x ' % b for b in array('B', data))))
+            ' '.join('%02x' % b for b in array('B', data))))
         return data
 
     def _send_asf_msg(self, msg):
@@ -352,7 +368,7 @@ class Rmcp(object):
 
     def _receive_asf_msg(self, cls):
         (_, class_of_msg, data) = self._receive()
-        log().debug('ASF: msg')
+        log().debug('ASF RX: msg')
         if class_of_msg != RMCP_CLASS_ASF:
             raise DecodingError('invalid class field in ASF message')
         msg = cls()
@@ -487,7 +503,7 @@ class Rmcp(object):
         """
         self._inc_sequence_number()
 
-        header = IpmbHeader()
+        header = IpmbHeaderReq()
         header.netfn = netfn
         header.rs_lun = lun
         header.rs_sa = target.ipmb_address
@@ -551,16 +567,6 @@ class Rmcp(object):
                                          netfn=req.netfn,
                                          cmdid=req.cmdid,
                                          payload=encode_message(req))
-        rsp = create_message(req.cmdid, req.netfn + 1)
+        rsp = create_message(req.netfn + 1, req.cmdid, req.group_extension)
         decode_message(rsp, rx_data)
         return rsp
-
-
-if __name__ == '__main__':
-    host = '10.0.114.199'
-    session = Session()
-    session.set_auth_type_user('admin', 'admin')
-
-    r = Rmcp(host)
-    r.ping()
-    r.establish_session(session)
