@@ -162,15 +162,23 @@ def print_sdr_list_entry(record_id, number, id_string, value, states):
     else:
         states = 'na'
 
-    print("0x%04x | %3s | %-16s | %9s | %s" % (record_id, number,
+    print("0x%04x | %3s | %-18s | %9s | %s" % (record_id, number,
                                                id_string, value, states))
 
 
 def cmd_sdr_list(ipmi, args):
-    print("SDR-ID |     | Device String    |")
-    print("=======|=====|==================|====================")
+    iter_fct = None
 
-    for s in ipmi.device_sdr_entries():
+    device_id = ipmi.get_device_id()
+    if device_id.supports_function('sdr_repository'):
+        iter_fct = ipmi.sdr_repository_entries
+    elif device_id.supports_function('sensor'):
+        iter_fct = ipmi.device_sdr_entries
+
+    print("SDR-ID |     | Device String      |")
+    print("=======|=====|====================|====================")
+
+    for s in iter_fct():
         try:
             number = None
             value = None
@@ -192,7 +200,7 @@ def cmd_sdr_list(ipmi, args):
         except pyipmi.errors.CompletionCodeError as e:
             if s.type in (pyipmi.sdr.SDR_TYPE_COMPACT_SENSOR_RECORD,
                           pyipmi.sdr.SDR_TYPE_FULL_SENSOR_RECORD):
-                print('0x{:04x} | {:3d} | {:16s} | ERR: CC=0x{:02x}'.format(
+                print('0x{:04x} | {:3d} | {:18s} | ERR: CC=0x{:02x}'.format(
                       s.id,
                       s.number,
                       s.device_id_string,
@@ -310,6 +318,7 @@ def cmd_hpm_check_file(ipmi, args):
 
 def cmd_hpm_install(ipmi, args):
     if len(args) < 2:
+        print('missing argument')
         return
     ipmi.install_component_from_file(args[0], int(args[1]))
 
@@ -429,7 +438,7 @@ Options:
   -h               Show this help
   -v               Be verbose
   -V               Print version
-  -I <interface>   Set interface (available: rmcp, aardvark ipmitool)
+  -I <interface>   Set interface (available: rmcp, aardvark, ipmitool)
   -H <host>        Set RMCP host
   -U <user>        Set RMCP user
   -P <password>    Set RMCP password
@@ -437,10 +446,13 @@ Options:
                    by commas, see below for available options).
 '''[1:])
         print('''
-Aardvark options:
+Aardvark interface options:
   serial=<SN>       Serial number of the device
   pullups=<on|off>  Enable/disable pullups
   power=<on|off>    Enable/disable target power
+
+Ipmitool interface options:
+  interface_type    Set the interface type to be used (lan, lanplus, serial)
 '''[1:])
         print('Commands:')
 
@@ -455,6 +467,36 @@ def version():
     print('ipmitool v%s' % pyipmi.__version__)
 
 
+def parse_interface_options(interface_name, options):
+    if options:
+        options = options.split(',')
+
+    interface_options = {}
+
+    for option in options:
+        (name, value) = option.split('=', 1)
+        if interface_name == 'aardvark':
+            if name == 'serial':
+                interface_options['serial_number'] = value
+            elif (name, value) == ('pullups', 'on'):
+                interface_options['enable_i2c_pullups'] = True
+            elif (name, value) == ('pullups', 'off'):
+                interface_options['enable_i2c_pullups'] = False
+            elif (name, value) == ('power', 'on'):
+                interface_options['enable_target_power'] = True
+            elif (name, value) == ('power', 'off'):
+                interface_options['enable_target_power'] = False
+            else:
+                print('Warning: unknown option %s' % name)
+        elif interface_name == 'ipmitool':
+            if name == 'interface_type':
+                interface_options['interface_type'] = value
+            else:
+                print('Warning: unknown option %s' % name)
+
+    return interface_options
+
+
 def main():
     try:
         opts, args = getopt.getopt(sys.argv[1:], 't:hvVI:H:U:P:o:b:p:r:')
@@ -465,7 +507,7 @@ def main():
     verbose = False
     interface_name = 'aardvark'
     target_address = 0x20
-    target_routing = [(0x20, 0, 0)]
+    target_routing = None
     rmcp_host = None
     rmcp_port = 623
     rmcp_user = ''
@@ -497,7 +539,8 @@ def main():
         elif o == '-I':
             interface_name = a
         elif o == '-o':
-            interface_options = a.split(',')
+            interface_options = a
+            #interface_options = a.split(',')
         else:
             assert False, 'unhandled option'
 
@@ -525,41 +568,16 @@ def main():
         usage()
         sys.exit(1)
 
-    aardvark_serial = None
-    aardvark_pullups = None
-    aardvark_target_power = None
-
-    for option in interface_options:
-        (name, value) = option.split('=', 1)
-        if (interface_name, name) == ('aardvark', 'serial'):
-            aardvark_serial = value
-        elif (interface_name, name, value) == ('aardvark', 'pullups', 'on'):
-            aardvark_pullups = True
-        elif (interface_name, name, value) == ('aardvark', 'pullups', 'off'):
-            aardvark_pullups = False
-        elif (interface_name, name, value) == ('aardvark', 'power', 'on'):
-            aardvark_target_power = True
-        elif (interface_name, name, value) == ('aardvark', 'power', 'off'):
-            aardvark_target_power = False
-        else:
-            print('Warning: unknown option %s' % name)
+    interface_options = parse_interface_options(interface_name,
+                                                interface_options)
 
     try:
-        if interface_name == 'aardvark':
-            interface = pyipmi.interfaces.create_interface(
-                                                interface_name,
-                                                serial_number=aardvark_serial)
-        else:
-            interface = pyipmi.interfaces.create_interface(interface_name)
+        interface = pyipmi.interfaces.create_interface(interface_name,
+                                                       **interface_options)
     except RuntimeError as e:
         print(e)
         sys.exit(1)
 
-    if aardvark_pullups:
-        interface.enable_pullups(aardvark_pullups)
-    if aardvark_target_power:
-        interface.enable_target_power(aardvark_target_power)
-
     ipmi = pyipmi.create_connection(interface)
     ipmi.target = pyipmi.Target(target_address)
 
