@@ -91,7 +91,19 @@ NETFN_TRANSPORT = 0x0c
 NETFN_GROUP_EXTENSION = 0x2c
 NETFN_OEM = 0x2e
 
-# IPM device 'global'
+NETFN_DESCR = (
+    (NETFN_CHASSIS, 'Chassis'),
+    (NETFN_BRIDGE, 'Bridge'),
+    (NETFN_SENSOR_EVENT, 'Sensor/Event'),
+    (NETFN_APP, 'App'),
+    (NETFN_FIRMWARE, 'Firmware'),
+    (NETFN_STORAGE, 'Storage'),
+    (NETFN_TRANSPORT, 'Transport'),
+    (NETFN_GROUP_EXTENSION, 'Group Extension'),
+    (NETFN_OEM, 'IANA'),
+)
+
+# IPM device 'global' .. NetFn App
 CMDID_GET_DEVICE_ID = 0x01
 CMDID_COLD_RESET = 0x02
 CMDID_WARM_RESET = 0x03
@@ -100,11 +112,21 @@ CMDID_MANUFACTURING_TEST_ON = 0x05
 CMDID_SET_ACPI_POWER_STATE = 0x06
 CMDID_GET_ACPI_POWER_STATE = 0x07
 CMDID_GET_DEVICE_GUID = 0x08
-# BMC watchdog timer
+CMDID_GET_NETFN_SUPPORT = 0x09
+CMDID_GET_COMMAND_SUPPORT = 0x0a
+CMDID_GET_COMMAND_SUBFUNCTION_SUPPORT = 0x0b
+CMDID_GET_CONFIGURATION_COMMANDS = 0x0c
+CMDID_GET_CONFIGURATION_SUBFUNCTION_COMMANDS = 0x0d
+CMDID_SET_COMMAND_ENABLES = 0x60
+CMDID_GET_COMMAND_ENABLES = 0x61
+CMDID_SET_COMMAND_SUBFUNCTION_ENABLES = 0x62
+CMDID_GET_COMMAND_SUBFUNCTION_ENABLES = 0x63
+CMDID_GET_OEM_NETFN_IANA_SUPPORT = 0x64
+# BMC watchdog timer .. NetFn App
 CMDID_RESET_WATCHDOG_TIMER = 0x22
 CMDID_SET_WATCHDOG_TIMER = 0x24
 CMDID_GET_WATCHDOG_TIMER = 0x25
-# BMC device and messaging
+# BMC device and messaging .. NetFn App
 CMDID_SET_BMC_GLOBAL_ENABLES = 0x2e
 CMDID_GET_BMC_GLOBAL_ENABLES = 0x2f
 CMDID_CLEAR_MESSAGE_FLAGS = 0x30
@@ -130,8 +152,23 @@ CMDID_GET_USER_ACCESS = 0x44
 CMDID_SET_USER_NAME = 0x45
 CMDID_GET_USER_NAME = 0x46
 CMDID_SET_USER_PASSWORD = 0x47
+CMDID_ACTIVATE_PAYLOAD = 0x48
+CMDID_DEACTIVATE_PAYLOAD = 0x49
+CMDID_GET_PAYLOAD_ACTITVATION_STATUS = 0x4a
+CMDID_GET_PAYLOAD_INSTANCE_INFO = 0x4b
+CMDID_SET_USER_PAYLOAD_ACCESS = 0x4c
+CMDID_GET_USER_PAYLOAD_ACCESS = 0x4d
+CMDID_GET_CHANNEL_PAYLOAD_SUPPORT = 0x4e
+CMDID_GET_CHANNEL_PAYLOAD_VERSION = 0x4f
+CMDID_GET_CHANNEL_OEM_PAYLOAD_INFO = 0x50
 CMDID_MASTER_WRITE_READ = 0x52
-# chassis device
+CMDID_GET_CHANNEL_CIPHER_SUITES = 0x54
+CMDID_SUSPEND_RESUME_PAYLOAD_ENCRYPTION = 0x55
+CMDID_SET_CHANNEL_SECURITY_KEYS = 0x56
+CMDID_GET_SYSTEM_INTERFACE_CAPABILITIES = 0x57
+CMDID_SET_SYSTEM_INFO_PARAMETERS = 0x58
+CMDID_GET_SYSTEM_INFO_PARAMETERS = 0x59
+# chassis device .. NetFn Chassis
 CMDID_GET_CHASSIS_CAPABILITIES = 0x00
 CMDID_GET_CHASSIS_STATUS = 0x01
 CMDID_CHASSIS_CONTROL = 0x02
@@ -143,12 +180,20 @@ CMDID_GET_SYSTEM_RESTART_CAUSE = 0x07
 CMDID_SET_SYSTEM_BOOT_OPTIONS = 0x08
 CMDID_GET_SYSTEM_BOOT_OPTIONS = 0x09
 CMDID_GET_POH_COUNTER = 0x0f
-# event
+# event .. NetFn S/E
 CMDID_SET_EVENT_RECEIVER = 0x00
 CMDID_GET_EVENT_RECEIVER = 0x01
 CMDID_PLATFORM_EVENT = 0x02
-# PEF and alerting
-# sensor device
+# PEF and alerting .. NetFn S/E
+CMDID_GET_PEF_CAPABILITIES = 0x10
+CMDID_ARM_PEF_POSTPONE_TIMER = 0x11
+CMDID_SET_PEFCONFIGURATION_PARAMETERS = 0x12
+CMDID_GET_PEFCONFIGURATION_PARAMETERS = 0x13
+CMDID_SET_LAST_PROCESSED_EVENT_ID = 0x14
+CMDID_GET_LAST_PROCESSED_EVENT_ID = 0x15
+CMDID_ALERT_IMMEDIATE = 0x16
+CMDID_PET_ACKNOWLEDGE = 0x17
+# sensor device .. NetFn S/E
 CMDID_GET_DEVICE_SDR_INFO = 0x20
 CMDID_GET_DEVICE_SDR = 0x21
 CMDID_RESERVE_DEVICE_SDR_REPOSITORY = 0x22
@@ -164,11 +209,12 @@ CMDID_GET_SENSOR_EVENT_STATUS = 0x2b
 CMDID_GET_SENSOR_READING = 0x2d
 CMDID_SET_SENSOR_TYPE = 0x2e
 CMDID_GET_SENSOR_TYPE = 0x2f
-# fru device
+CMDID_SET_SENSOR_READING_AND_EVENT_STATUS = 0x30
+# fru device .. NetFn Storage
 CMDID_GET_FRU_INVENTORY_AREA_INFO = 0x10
 CMDID_READ_FRU_DATA = 0x11
 CMDID_WRITE_FRU_DATA = 0x12
-# SDR device
+# SDR device .. NetFn Storage
 CMDID_GET_SDR_REPOSITORY_INFO = 0x20
 CMDID_GET_SDR_REPOSITORY_ALLOCATION_INFO = 0x21
 CMDID_RESERVE_SDR_REPOSITORY = 0x22
@@ -182,7 +228,7 @@ CMDID_SET_SDR_REPOSITORY_TIME = 0x29
 CMDID_ENTER_SDR_REPOSITORY_UPDATE_MODE = 0x2a
 CMDID_EXIT_SDR_REPOSITORY_UPDATE_MODE = 0x2b
 CMDID_RUN_INITIALIZATION_AGENT = 0x2c
-# SEL device
+# SEL device .. NetFn Storage
 CMDID_GET_SEL_INFO = 0x40
 CMDID_GET_SEL_ALLOCATION_INFO = 0x41
 CMDID_RESERVE_SEL = 0x42
@@ -195,18 +241,22 @@ CMDID_GET_SEL_TIME = 0x48
 CMDID_SET_SEL_TIME = 0x49
 CMDID_GET_AUXILIARY_LOG_STATUS = 0x5a
 CMDID_SET_AUXILIARY_LOG_STATUS = 0x5b
-# LAN device
+CMDID_GET_SEL_TIME_UTC_OFFSET = 0x5c
+CMDID_SET_SEL_TIME_UTC_OFFSET = 0x5d
+# LAN device .. NetFn Transport
 CMDID_SET_LAN_CONFIGURATION_PARAMETERS = 0x01
 CMDID_GET_LAN_CONFIGURATION_PARAMETERS = 0x02
 CMDID_SUSPEND_BMC_ARPS = 0x03
 CMDID_GET_IP_UDP_RMCP_STATISTICS = 0x04
-# Serial/Modem device
-# bridge management (ICMB)
-# discovery (ICMB)
-# bridging (ICMB)
-# event (ICMB)
-# other (ICMB)
-# PICMG commands
+# Serial/Modem device .. NetFn Transport
+# Command Forwarding .. NetFn Transport
+# bridge management (ICMB) .. NetFn Bridge
+# discovery (ICMB) .. NetFn Bridge
+# bridging (ICMB) .. NetFn Bridge
+# event (ICMB) .. NetFn Bridge
+# other (ICMB) .. NetFn Bridge
+
+# PICMG commands .. NetFn Group Extension (ID 0)
 CMDID_GET_PICMG_PROPERTIES = 0x00
 CMDID_GET_ADDRESS_INFO = 0x01
 CMDID_GET_SHELF_ADDRESS_INFO = 0x02
@@ -242,10 +292,10 @@ CMDID_GET_SHELF_MANAGER_IP_ADDRESSES = 0x21
 CMDID_GET_SHELF_POWER_ALLOCATION = 0x22
 CMDID_SET_CHANNEL_SIGNALING_CLASS = 0x3b
 CMDID_GET_CHANNEL_SIGNALING_CLASS = 0x3c
-# AdvancedMC
+# PICMG AdvancedMC .. NetFn Group Extension (ID 0)
 CMDID_SET_AMC_PORT_STATE = 0x19
 CMDID_GET_AMC_PORT_STATE = 0x1a
-# MicroTCA
+# PICMG MicroTCA .. NetFn Group Extension (ID 0)
 CMDID_GET_LOCATION_INFO = 0x23
 CMDID_POWER_CHANNEL_CONTROL = 0x24
 CMDID_GET_POWER_CHANNEL_STATUS = 0x25
@@ -256,7 +306,7 @@ CMDID_GET_TELCO_ALARM_CAPABILITY = 0x29
 CMDID_SET_TELCO_ALARM_STATE = 0x2a
 CMDID_GET_TELCO_ALARM_STATE = 0x2b
 
-# HPM.1 commands
+# PICMG HPM.1 commands .. NetFn Group Extension (ID 0)
 CMDID_HPM_GET_TARGET_UPGRADE_CAPABILITIES = 0x2e
 CMDID_HPM_GET_COMPONENT_PROPERTIES = 0x2f
 CMDID_HPM_ABORT_FIRMWARE_UPGRADE = 0x30
@@ -269,6 +319,18 @@ CMDID_HPM_QUERY_SELFTEST_RESULTS = 0x36
 CMDID_HPM_QUERY_ROLLBACK_STATUS = 0x37
 CMDID_HPM_INITIATE_MANUAL_ROLLBACK = 0x38
 
+# DCMI commands .. NetFn Group Extension (ID 0xdc)
+CMDID_GET_DCMI_CAPABILITIES_INFO = 0x01
+CMDID_GET_POWER_READING = 0x02
+CMDID_GET_POWER_LIMIT = 0x03
+CMDID_SET_POWER_LIMIT = 0x04
+CMDID_ACTIVATE_DEACTIVATE_POWER_LIMIT = 0x05
+CMDID_GET_ASSET_TAG = 0x06
+CMDID_GET_DCMI_SENSOR_INFO = 0x07
+CMDID_SET_ASSET_TAG = 0x08
+CMDID_GET_MANAGEMENT_CONTROLLER_ID_STRING = 0x09
+CMDID_SET_MANAGEMENT_CONTROLLER_ID_STRING = 0x0a
+
 cc_err_cmd_specific_desc = {
     CMDID_GET_SESSION_CHALLENGE: {
         0x81: 'invalid user name',
