@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 # Copyright (c) 2014  Kontron Europe GmbH
 #
 # This library is free software; you can redistribute it and/or
@@ -12,21 +13,19 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
-import constants
+from . import constants
 
 from . import register_message_class
 from . import Message
 from . import UnsignedInt
-from . import UnsignedIntMask
-from . import Timestamp
 from . import Bitfield
 from . import CompletionCode
-from . import Conditional
 from . import RemainingBytes
 from . import VariableByteArray
 
+
 @register_message_class
 class GetFruInventoryAreaInfoReq(Message):
     __cmdid__ = constants.CMDID_GET_FRU_INVENTORY_AREA_INFO
@@ -44,9 +43,8 @@ class GetFruInventoryAreaInfoRsp(Message):
         CompletionCode(),
         UnsignedInt('area_size', 2),
         Bitfield('area_info', 1,
-            Bitfield.Bit('access', 1),
-            Bitfield.ReservedBit(7,0)
-        ),
+                 Bitfield.Bit('access', 1),
+                 Bitfield.ReservedBit(7, 0)),
     )
 
 
@@ -55,9 +53,9 @@ class ReadFruDataReq(Message):
     __cmdid__ = constants.CMDID_READ_FRU_DATA
     __netfn__ = constants.NETFN_STORAGE
     __fields__ = (
-            UnsignedInt('fru_id', 1),
-            UnsignedInt('offset', 2),
-            UnsignedInt('count', 1),
+        UnsignedInt('fru_id', 1),
+        UnsignedInt('offset', 2),
+        UnsignedInt('count', 1),
     )
 
 
@@ -70,9 +68,9 @@ class ReadFruDataRsp(Message):
         return obj.count
 
     __fields__ = (
-            CompletionCode(),
-            UnsignedInt('count', 1),
-            VariableByteArray('data', _length_count),
+        CompletionCode(),
+        UnsignedInt('count', 1),
+        VariableByteArray('data', _length_count),
     )
 
 
