@@ -237,7 +237,7 @@ class Bitfield(BaseField):
             for attr in dir(self):
                 if attr.startswith('_'):
                     continue
-                s += '%s=%s ' % (attr, getattr(self, attr))
+                s += '%s=%s, ' % (attr, getattr(self, attr))
             s += ']'
             return s
 
@@ -299,10 +299,17 @@ class Bitfield(BaseField):
         return Bitfield.BitWrapper(self._bits, self.length)
 
 
+class GroupExtensionIdentifier(UnsignedInt):
+    def __init__(self, name='picmg_identifier', value=None):
+        UnsignedInt.__init__(self, name, 1, value)
+
+
 class Message(object):
-    RESERVED_FIELD_NAMES = ['cmdid', 'netfn', 'lun']
+    RESERVED_FIELD_NAMES = ['cmdid', 'netfn', 'lun', 'group_extension']
 
     __default_lun__ = 0
+    __group_extension__ = None
+    __not_implemented__ = False
 
     def __init__(self, *args, **kwargs):
         """Message constructor with ([buf], [field=val,...]) prototype.
@@ -389,6 +396,7 @@ class Message(object):
 
     netfn = property(lambda s: s.__netfn__)
     cmdid = property(lambda s: s.__cmdid__)
+    group_extension = property(lambda s: s.__group_extension__)
 
 
 encode_message = lambda m: m._encode()
