@@ -93,7 +93,7 @@ class Sdr(object):
         """A generator that returns the SDR list. Starting with ID=0x0000 and
         end when ID=0xffff is returned.
         """
-        reservation_id = self.reserve_device_sdr_repository()
+        reservation_id = self.reserve_sdr_repository()
         record_id = 0
 
         while True:
@@ -220,6 +220,11 @@ class SdrCommon(object):
         self.entity_id = buffer.pop_unsigned_int(1)
         self.entity_instance = buffer.pop_unsigned_int(1)
 
+    def _device_id_string(self, buffer):
+        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
+        self.device_id_string = \
+            buffer.pop_string(self.device_id_string_type_length & 0x3f)
+
     @staticmethod
     def from_data(data, next_id=None):
         sdr_type = data[3]
@@ -412,13 +417,13 @@ class SdrFullSensorRecord(SdrCommon):
         self.deassertion_mask = buffer.pop_unsigned_int(2)
         self.discrete_reading_mask = buffer.pop_unsigned_int(2)
         # byte 21, 22, 23
-        units_1 = buffer.pop_unsigned_int(1)
-        units_2 = buffer.pop_unsigned_int(1)
-        units_3 = buffer.pop_unsigned_int(1)
-        self.analog_data_format = (units_1 >> 6) & 0x3
-        self.rate_unit = (units_1 >> 3) >> 0x7
-        self.modifier_unit = (units_1 >> 1) & 0x2
-        self.percentage = units_1 & 0x1
+        self.units_1 = buffer.pop_unsigned_int(1)
+        self.units_2 = buffer.pop_unsigned_int(1)
+        self.units_3 = buffer.pop_unsigned_int(1)
+        self.analog_data_format = (self.units_1 >> 6) & 0x3
+        self.rate_unit = (self.units_1 >> 3) >> 0x7
+        self.modifier_unit = (self.units_1 >> 1) & 0x2
+        self.percentage = self.units_1 & 0x1
         # byte 24
         self.linearization = buffer.pop_unsigned_int(1) & 0x7f
         # byte 25, 26
@@ -475,8 +480,7 @@ class SdrFullSensorRecord(SdrCommon):
         self.hysteresis['negative_going'] = buffer.pop_unsigned_int(1)
         self.reserved = buffer.pop_unsigned_int(2)
         self.oem = buffer.pop_unsigned_int(1)
-        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = py3dec_unic_bytes_fix(buffer.tostring())
+        self._device_id_string(buffer)
 
 
 ###
@@ -518,8 +522,7 @@ class SdrCompactSensorRecord(SdrCommon):
         self.negative_going_hysteresis = buffer.pop_unsigned_int(1)
         self.reserved = buffer.pop_unsigned_int(3)
         self.oem = buffer.pop_unsigned_int(1)
-        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = py3dec_unic_bytes_fix(buffer.tostring())
+        self._device_id_string(buffer)
 
 
 ###
@@ -548,8 +551,7 @@ class SdrEventOnlySensorRecord(SdrCommon):
         self.record_sharing = buffer.pop_unsigned_int(2)
         self.reserved = buffer.pop_unsigned_int(1)
         self.oem = buffer.pop_unsigned_int(1)
-        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = py3dec_unic_bytes_fix(buffer.tostring())
+        self._device_id_string(buffer)
 
 
 ###
@@ -578,8 +580,7 @@ class SdrFruDeviceLocator(SdrCommon):
         self.device_type_modifier = buffer.pop_unsigned_int(1)
         self._entity(buffer.pop_slice(2))
         self.oem = buffer.pop_unsigned_int(1)
-        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = py3dec_unic_bytes_fix(buffer.tostring())
+        self._device_id_string(buffer)
 
 
 ###
@@ -608,8 +609,7 @@ class SdrManagementControllerDeviceLocator(SdrCommon):
         self.reserved = buffer.pop_unsigned_int(3)
         self._entity(buffer.pop_slice(2))
         self.oem = buffer.pop_unsigned_int(1)
-        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = py3dec_unic_bytes_fix(buffer.tostring())
+        self._device_id_string(buffer)
 
 
 ###
